function [avg_energy t60 slope_vector m] = t60_calc(IR, fs)
%% calculate t60 of input IR

window_length = 10*fs/1000; %50 ms in samples
window = ones(window_length, 1) / window_length;

avg_energy = sqrt(fftfilt(window, IR.^2));
figure;
hold on;
plot(0:length(IR)-1, db(abs(IR)), 'Color',[0.6 0.6 0.6]);
plot(0:length(IR)-1, db(abs(avg_energy)), 'black');
ylabel('dB');
hold off;
title('Pick 2 points on x-axis to zoom for t60 calculation');
xlabel('time (samples)');
[x_axis y_axis] = ginput(2);
x_axis1 = round(x_axis(1));
x_axis2 = round(x_axis(2));
if x_axis1 > x_axis2
    x_temp = x_axis2;
    x_axis2 = x_axis1;
    x_axis1 = x_temp;
end;
close(gcf);
figure;
hold on;
plot(x_axis1:x_axis2, db(abs(IR(x_axis1:x_axis2))), 'Color',[0.6 0.6 0.6]);
plot(x_axis1:x_axis2, db(abs(avg_energy(x_axis1:x_axis2))), 'black');
ylabel('dB');
xlabel('time (samples)');
title('Pick 2 points on the black line for t60 decay time calculation');

[x y] = ginput(2);
x1 = round(x(1))
x2 = round(x(2))
if x1 > x2
    x_temp = x2;
    x2 = x1;
    x1 = x_temp;
end;
slope_vector = x1:x2;
plot(slope_vector, db(abs(avg_energy(slope_vector))), 'Color', 'green');
X = slope_vector;
Y = db(abs(avg_energy(slope_vector)));
m = polyfit(X', Y, 1);
plot(slope_vector, m(1)*slope_vector + m(2), 'Color', 'red');
hold off;
t60 = (1/(m(1)*fs))*-60;
title('IR');
xlabel(['t60 = ' num2str(t60) ' seconds' ]);
ylabel('dB');
disp(['the t60 for the IR is: ' num2str(t60) ' seconds']);
close(gcf);
